# Charles Kurzman, analysis of Carnegie Mellon University Delphi COVID-19 survey data

library(ggplot2)
library(dplyr)
library(readxl)
#install.packages("patchwork")
library(patchwork)

setwd("c:/")

filelist <- list.files()

filename <-filelist[1]
week <- read.csv(filename, stringsAsFactors = FALSE)
#weekline <- reshape(week, idvar="mc_race_ethnicity_age_18to64", timevar="mc_ifwhere_working", direction = "wide")
week$date <- as.Date(substr(filename,1,8), "%Y%m%d")
week$sum <- ave(week$represented_pct_tested_pos_2w, week$mc_race_ethnicity_age_18to64, FUN=sum)
d <- week

for(f in 2:length(filelist)){
  filename <-filelist[f]
  week <- read.csv(filename, stringsAsFactors = FALSE)
  #weekline <- reshape(week, idvar="mc_race_ethnicity_age_18to64", timevar="mc_ifwhere_working", direction = "wide")
  week$date <- as.Date(substr(filename,1,8), "%Y%m%d")
  week$sum <- ave(week$represented_pct_tested_pos_2w, week$mc_race_ethnicity_age_18to64, FUN=sum)
  d <- rbind(d, week)
}

d$pct <- 100*d$represented_pct_tested_pos_2w/d$sum
d$ci_l <- d$val_pct_tested_pos_2w - (1.96*d$se_pct_tested_pos_2w)
d$ci_u <- d$val_pct_tested_pos_2w + (1.96*d$se_pct_tested_pos_2w)
ggplot(d[d$mc_ifwhere_working=="Working but not outside the home",], aes(x=date, y=pct, color=mc_race_ethnicity_age_18to64)) + geom_smooth()
ggplot(d[d$mc_ifwhere_working=="Working outside the home",], aes(x=date, y=pct, color=mc_race_ethnicity_age_18to64)) + geom_smooth()
ggplot(d[d$mc_ifwhere_working=="Not working",], aes(x=date, y=pct, color=mc_race_ethnicity_age_18to64)) + geom_smooth()


pw <- ggplot(d[d$mc_race_ethnicity_age_18to64=="Non-Hispanic White" & d$mc_ifwhere_working!="Not working",], aes(x=date, y=`val_pct_tested_pos_2w`, color=mc_ifwhere_working)) +
  geom_point(size=0.3) +
  geom_smooth(se = FALSE, size=0.3) +
  geom_linerange(aes(ymin = ci_l, ymax = ci_u), alpha = 0.6) + 
  scale_color_manual(values=c("Blue","Black"), guide=FALSE) +
  scale_y_continuous(breaks = seq(0,5, by=1)) + expand_limits(y = 5.5) + expand_limits(y = 0) +
  ylab("Percent testing positive for Covid-19\nin previous two weeks") + xlab("") +
  theme(panel.background=element_blank()) +
  scale_x_date(date_breaks = "1 month", date_labels = "%b") +
  annotate(geom="text",x=as.Date("2020-09-13"), y=5, label="Non-Hispanic White\nrespondents", hjust="left", size=3.5, color="black") +
  annotate(geom="text",x=as.Date("2020-12-15"), y=3.6, label="Working", hjust="left", size=3.5, color="black") +
  annotate(geom="text",x=as.Date("2020-12-15"), y=3.3, label="outside home", hjust="left", size=3.5, color="black") +
  annotate(geom="text",x=as.Date("2020-10-15"), y=0.5, label="Working", hjust="left", size=3.5, color="blue") +
  annotate(geom="text",x=as.Date("2020-10-15"), y=0.2, label="at home", hjust="left", size=3.5, color="blue")

pb <- ggplot(d[d$mc_race_ethnicity_age_18to64=="Non-Hispanic Black" & d$mc_ifwhere_working!="Not working",], aes(x=date, y=`val_pct_tested_pos_2w`, color=mc_ifwhere_working)) +
  geom_point(size=0.3) +
  geom_smooth(se = FALSE, size=0.3) +
  geom_linerange(aes(ymin = ci_l, ymax = ci_u), alpha = 0.6) + 
  scale_color_manual(values=c("Blue","Black"), guide=FALSE) +
  scale_y_continuous(breaks = seq(0,5, by=1)) + expand_limits(y = 5.5) + expand_limits(y = 0) +
  ylab("") + theme(axis.text.y = element_blank()) + theme(axis.ticks.y = element_blank()) +
  theme(panel.background=element_blank()) +
  xlab("Sept. 8, 2020-March 20, 2021\n(weekly totals)") +
  scale_x_date(date_breaks = "1 month", date_labels = "%b") +
  annotate(geom="text",x=as.Date("2020-09-13"), y=5, label="Non-Hispanic Black\nrespondents", hjust="left", size=3.5, color="black")

ph <- ggplot(d[d$mc_race_ethnicity_age_18to64=="Hispanic" & d$mc_ifwhere_working!="Not working",], aes(x=date, y=`val_pct_tested_pos_2w`, color=mc_ifwhere_working)) +
  geom_point(size=0.3) +
  geom_smooth(se = FALSE, size=0.3) +
  geom_linerange(aes(ymin = ci_l, ymax = ci_u), alpha = 0.6) + 
  scale_color_manual(values=c("Blue","Black"), guide=FALSE) +
  scale_y_continuous(breaks = seq(0,5, by=1)) + expand_limits(y = 5.5) + expand_limits(y = 0) +
  ylab("") + xlab("") + theme(axis.text.y = element_blank()) + theme(axis.ticks.y = element_blank()) +
  theme(panel.background=element_blank()) +
  scale_x_date(date_breaks = "1 month", date_labels = "%b") +
  annotate(geom="text",x=as.Date("2020-09-13"), y=5, label="Hispanic\nrespondents", hjust="left", size=3.5, color="black")


pall <- (pw + pb + ph) +
  plot_annotation(title = "Working at/outside home and Covid-19 infection rates, by race and Hispanic ethnicity",
                  caption = "Percent of respondents age 18-64 testing positive for Covid-19 in previous two weeks, with 95 percent confidence intervals.\nCharles Kurzman, UNC-Chapel Hill, March 31, 2021.\nSurvey data: Delphi Research Group, Carnegie Mellon University.") &
  theme(plot.title = element_text(hjust = 0.3))

pall

ggsave("Kurzman-Working-Home-Covid-19-Race-Hispanic-Ethnicity-2021-03-31.png", dpi=300, height=4, width=8)

d2 <- aggregate(d$pct, by = list(d$mc_ifwhere_working, d$mc_race_ethnicity_age_18to64), FUN = mean)
d2

ggplot(data=d2[d2$Group.2!="Non-Hispanic Asian",], aes(x=Group.2, y=x, fill=Group.1)) + 
  geom_bar(stat="identity") + xlab("Identity Selected by Survey Respondents\n(September 8, 2020 - March 20, 2021)") +
  ylab("Percent") + theme(legend.position="top") + labs(fill="") +
  scale_y_continuous(breaks = seq(0,100, by=10)) +
  theme(panel.background=element_blank()) + theme(axis.ticks.x = element_blank()) +
  labs(title="Percent working at/outside home, by race and Hispanic ethnicity") + 
  labs(caption="Percent of respondents age 18-64.\nCharles Kurzman, UNC-Chapel Hill, March 31, 2021.\nSurvey data: Delphi Research Group, Carnegie Mellon University.")

ggsave("Kurzman-Working-Home-Percent-Race-Hispanic-Ethnicity-2021-03-31.png", dpi=300, height=4, width=6)
